@@ -6,7 +6,7 @@ from redis.commands.core import CoreCommands
 
 class RedisClientWithRetry(object):
 
-    methods = (c for c in dir(CoreCommands) + ['pipeline',
+    __methods = (c for c in dir(CoreCommands) + ['pipeline',
                                                'get_connection_kwargs',
                                                'register_script']
                if not c.startswith('_'))
@@ -23,7 +23,7 @@ class RedisClientWithRetry(object):
         return cls(redis_client=redis_client, max_retry=max_retry)
 
     def attach_methods(self):
-        for method in self.methods:
+        for method in self.__methods:
             if not hasattr(self, method):
                 setattr(self, method, partial(self._run_method, method))
 
